==> ongaku-desktop-1.0.6.tgz: package/README.md <==
# ongaku-desktop [<img src="https://rawgit.com/sindresorhus/awesome-electron/master/electron-logo.svg" align="right" width="100">](https://electron.atom.io/) [![js-standard-style](https://img.shields.io/badge/code%20style-standard-brightgreen.svg)](http://standardjs.com/) [![npm](https://img.shields.io/npm/dt/ongaku-desktop.svg)](https://www.npmjs.com/package/ongaku-desktop) [![npm](https://img.shields.io/npm/v/ongaku-desktop.svg)](https://www.npmjs.com/package/ongaku-desktop) [![SourceForge](https://img.shields.io/sourceforge/dt/ongaku.svg)](https://sourceforge.net/projects/ongaku/)

> Electron based desktop port of [ongaku](https://ongaku.js.org).

Play anime music with ease on your desktop. Uses [ongaku](https://github.com/anshumanv/ongaku) web-app under the hood.

### Screenshots

![sample1](https://user-images.githubusercontent.com/21009455/29402408-71be8202-8352-11e7-8464-96a94f049395.PNG)
![sample2](https://user-images.githubusercontent.com/21009455/29402450-96dd252a-8352-11e7-921c-7e30e3aab1ca.PNG)


## Install and Run

```
$ npm install -g ongaku-desktop
$ ongaku
# may need to install electron
# sudo npm install electron -g
```

## Dev

```
$ git clone --recursive https://github.com/Anshuman-Verma/ongaku-desktop.git
$ cd ongaku-desktop
$ npm install
$ npm start
```

### Build

```
$ npm run build
```

### Downloads

[<img src="https://assets.windowsphone.com/f2f77ec7-9ba9-4850-9ebe-77e366d08adc/English_Get_it_Win_10_InvariantCulture_Default.png" align="center" width="100">](https://sourceforge.net/projects/ongaku/)

## License

MIT © [Anshuman Verma](https://twitter.com/Anshumaniac12)

==> ongaku-desktop-1.0.12.tgz: package/README.md <==
# ongaku-desktop [<img src="https://rawgit.com/sindresorhus/awesome-electron/master/electron-logo.svg" align="right" width="100">](https://electron.atom.io/) [![js-standard-style](https://img.shields.io/badge/code%20style-standard-brightgreen.svg)](http://standardjs.com/) [![npm](https://img.shields.io/npm/dt/ongaku-desktop.svg)](https://www.npmjs.com/package/ongaku-desktop) [![npm](https://img.shields.io/npm/v/ongaku-desktop.svg)](https://www.npmjs.com/package/ongaku-desktop) [![SourceForge](https://img.shields.io/sourceforge/dt/ongaku.svg)](https://sourceforge.net/projects/ongaku/)

> Electron based desktop port of [ongaku](https://ongaku.js.org).

Play anime music with ease on your desktop. Uses [ongaku](https://github.com/anshumanv/ongaku) web-app under the hood.

### Screenshots

![sample1](https://user-images.githubusercontent.com/23422478/35113761-a2094da0-fca8-11e7-8f84-f9b95d3d8276.PNG)
![sample2](https://user-images.githubusercontent.com/23422478/35113789-b9593a56-fca8-11e7-8ea9-200bf347ec4a.PNG)


## Install and Run

```
$ npm install -g ongaku-desktop
$ ongaku
# may need to install electron
# sudo npm install electron -g
```

## Dev

```
$ git clone --recursive https://github.com/Anshuman-Verma/ongaku-desktop.git
$ cd ongaku-desktop
$ npm install
$ npm start
```

### Build

```
$ npm run build
```

### Downloads

[<img src="https://assets.windowsphone.com/f2f77ec7-9ba9-4850-9ebe-77e366d08adc/English_Get_it_Win_10_InvariantCulture_Default.png" align="center" width="100">](https://sourceforge.net/projects/ongaku/)

## License

MIT © [Anshuman Verma](https://twitter.com/Anshumaniac12)
